# ObjectRef

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**api_version** | **str** | API version of the referent operation | [optional] 
**kind** | **str** | Kind specifies the type of the referent operation | [default to '']
**name** | **str** | Name specifies the name of the referent operation | [default to '']
**namespace** | **str** | Namespace specifies the namespace of the referent operation. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


